@@ -89,11 +89,16 @@ class LoadBalancerTests(test.TestCase):
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
                                     'pool_health_monitor_list'),
                         api.network: ('floating_ip_supported',
-                                      'floating_ip_simple_associate_supported')
+                                      'floating_ip_simple_associate_supported',
+                                      'tenant_floating_ip_list')
                         })
     def test_index_pools(self):
+        fips = self.floating_ips.list()
         self.set_up_expect()
 
+        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
+            AndReturn(fips)
+
         self.mox.ReplayAll()
 
         res = self.client.get(self.INDEX_URL)
@@ -107,11 +112,16 @@ class LoadBalancerTests(test.TestCase):
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
                                     'pool_health_monitor_list'),
                         api.network: ('floating_ip_supported',
-                                      'floating_ip_simple_associate_supported')
+                                      'floating_ip_simple_associate_supported',
+                                      'tenant_floating_ip_list')
                         })
     def test_index_members(self):
+        fips = self.floating_ips.list()
         self.set_up_expect()
 
+        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
+            AndReturn(fips)
+
         self.mox.ReplayAll()
 
         res = self.client.get(self.INDEX_URL + '?tab=lbtabs__members')
@@ -125,11 +135,16 @@ class LoadBalancerTests(test.TestCase):
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
                                     'pool_health_monitor_list'),
                         api.network: ('floating_ip_supported',
-                                      'floating_ip_simple_associate_supported')
+                                      'floating_ip_simple_associate_supported',
+                                      'tenant_floating_ip_list')
                         })
     def test_index_monitors(self):
+        fips = self.floating_ips.list()
         self.set_up_expect()
 
+        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
+            AndReturn(fips)
+
         self.mox.ReplayAll()
 
         res = self.client.get(self.INDEX_URL + '?tab=lbtabs__monitors')
@@ -584,6 +599,37 @@ class LoadBalancerTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
+    @test.create_stubs({api.lbaas: ('pool_list', 'pool_get', 'member_create'),
+                        api.neutron: ('port_list',),
+                        api.nova: ('server_list',)})
+    def test_add_member_no_ports(self):
+        member = self.members.first()
+        pools = self.pools.list()
+        server1 = self.AttributeDict({'id':
+                                      '12381d38-c3eb-4fee-9763-12de3338042e',
+                                      'name': 'vm1'})
+        api.lbaas.pool_list(
+            IsA(http.HttpRequest), tenant_id=self.tenant.id).AndReturn(pools)
+        api.nova.server_list(
+            IsA(http.HttpRequest)).AndReturn([[server1, ], False])
+        api.lbaas.pool_get(
+            IsA(http.HttpRequest), pools[1].id).AndReturn(pools[1])
+        api.neutron.port_list(
+            IsA(http.HttpRequest), device_id=server1.id).AndReturn([])
+
+        form_data = {'pool_id': member.pool_id,
+                     'protocol_port': member.protocol_port,
+                     'members': [server1.id],
+                     'admin_state_up': member.admin_state_up,
+                     'member_type': 'server_list'}
+
+        self.mox.ReplayAll()
+
+        res = self.client.post(reverse(self.ADDMEMBER_PATH), form_data)
+
+        self.assertNoFormErrors(res)
+        self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
+
     @test.create_stubs({api.lbaas: ('pool_list',),
                         api.nova: ('server_list',)})
     def test_add_member_post_with_error(self):
@@ -911,16 +957,20 @@ class LoadBalancerTests(test.TestCase):
             '<DeletePMAssociationStep: deletepmassociationaction>', ]
         self.assertQuerysetEqual(workflow.steps, expected_objs)
 
-    @test.create_stubs({api.lbaas: ('pool_list', 'pool_delete')})
+    @test.create_stubs({api.lbaas: ('pool_list', 'pool_delete'),
+                        api.network: ('tenant_floating_ip_list',)})
     def test_delete_pool(self):
         pool_list = self.pools.list()
         pool = pool_list[0]
+        fips = self.floating_ips.list()
         # the test pool needs to have no vip
         # in order to be able to be deleted
         pool.vip_id = None
         api.lbaas.pool_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(pool_list)
+        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
+            AndReturn(fips)
         api.lbaas.pool_delete(IsA(http.HttpRequest), pool.id)
         self.mox.ReplayAll()
 
@@ -930,13 +980,16 @@ class LoadBalancerTests(test.TestCase):
         self.assertNoFormErrors(res)
 
     @test.create_stubs({api.lbaas: ('pool_list', 'pool_get',
-                                    'vip_delete'),
+                                    'member_list', 'vip_delete',
+                                    'pool_health_monitor_list'),
                         api.network: (
+                            'tenant_floating_ip_list',
                             'floating_ip_supported',
                             'floating_ip_simple_associate_supported')})
     def test_delete_vip(self):
         pool = self.pools.first()
         vip = self.vips.first()
+        fips = self.floating_ips.list()
         api.lbaas.pool_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
@@ -945,6 +998,8 @@ class LoadBalancerTests(test.TestCase):
             .AndReturn(True)
         api.network.floating_ip_simple_associate_supported(IgnoreArg()) \
             .MultipleTimes().AndReturn(True)
+        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
+            AndReturn(fips)
         api.lbaas.vip_delete(IsA(http.HttpRequest), vip.id)
         self.mox.ReplayAll()
 
